.. _install:

*******
Install
*******

Regular install
===============

To install sigc run:

.. code-block:: bash

    git clone https://github.com/seqyuan/sigc
    cd sigc
    pip install .

Depending on your pip version, you may need to run this pip command instead:

.. code-block:: bash

    pip install -e .

Checking version
================

To check your sigc version

.. code-block:: python

    import sigc
    sigc.__version__

